
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.LoginAccountPwd;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.LoginAccountPwdFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class LoginAccountPwdService {

    LoginAccountPwdFeignClient client;

    @Autowired
    public LoginAccountPwdService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(LoginAccountPwdFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(LoginAccountPwdFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean checkKey(LoginAccountPwd loginaccountpwd) {
        return client.checkKey(loginaccountpwd);
    }

    public LoginAccountPwd update(String loginaccountpwd_id, LoginAccountPwd loginaccountpwd) {
        return client.update(loginaccountpwd_id, loginaccountpwd);
    }

    public boolean remove( String loginaccountpwd_id) {
        return client.remove( loginaccountpwd_id);
    }

    public LoginAccountPwd get( String loginaccountpwd_id) {
        return client.get( loginaccountpwd_id);
    }

    public LoginAccountPwd save(String loginaccountpwd_id, LoginAccountPwd loginaccountpwd) {
        return client.save(loginaccountpwd_id, loginaccountpwd);
    }

	public LoginAccountPwd create(LoginAccountPwd loginaccountpwd) {
        return client.create(loginaccountpwd);
    }

    public LoginAccountPwd getDraft(String loginaccountpwd_id, LoginAccountPwd loginaccountpwd) {
        return client.getDraft(loginaccountpwd_id, loginaccountpwd);
    }

	public Page<LoginAccountPwd> fetchDefault(LoginAccountPwdSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
