
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserGroupDetail;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserGroupDetailFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserGroupDetailService {

    UserGroupDetailFeignClient client;

    @Autowired
    public UserGroupDetailService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserGroupDetailFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserGroupDetailFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

    public UserGroupDetail get( String usergroupdetail_id) {
        return client.get( usergroupdetail_id);
    }

    public UserGroupDetail getDraft(String usergroupdetail_id, UserGroupDetail usergroupdetail) {
        return client.getDraft(usergroupdetail_id, usergroupdetail);
    }

	public UserGroupDetail create(UserGroupDetail usergroupdetail) {
        return client.create(usergroupdetail);
    }

    public UserGroupDetail save(String usergroupdetail_id, UserGroupDetail usergroupdetail) {
        return client.save(usergroupdetail_id, usergroupdetail);
    }

    public boolean checkKey(UserGroupDetail usergroupdetail) {
        return client.checkKey(usergroupdetail);
    }

    public UserGroupDetail update(String usergroupdetail_id, UserGroupDetail usergroupdetail) {
        return client.update(usergroupdetail_id, usergroupdetail);
    }

    public boolean remove( String usergroupdetail_id) {
        return client.remove( usergroupdetail_id);
    }

	public Page<UserGroupDetail> fetchDefault(UserGroupDetailSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
