
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserGroup;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserGroupFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserGroupService {

    UserGroupFeignClient client;

    @Autowired
    public UserGroupService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserGroupFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserGroupFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

	public UserGroup create(UserGroup usergroup) {
        return client.create(usergroup);
    }

    public UserGroup save(String usergroup_id, UserGroup usergroup) {
        return client.save(usergroup_id, usergroup);
    }

    public boolean checkKey(UserGroup usergroup) {
        return client.checkKey(usergroup);
    }

    public UserGroup getDraft(String usergroup_id, UserGroup usergroup) {
        return client.getDraft(usergroup_id, usergroup);
    }

    public UserGroup get( String usergroup_id) {
        return client.get( usergroup_id);
    }

    public UserGroup update(String usergroup_id, UserGroup usergroup) {
        return client.update(usergroup_id, usergroup);
    }

    public boolean remove( String usergroup_id) {
        return client.remove( usergroup_id);
    }

	public Page<UserGroup> fetchDefault(UserGroupSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
