
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserRoleDataAction;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserRoleDataActionFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserRoleDataActionService {

    UserRoleDataActionFeignClient client;

    @Autowired
    public UserRoleDataActionService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDataActionFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDataActionFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

    public UserRoleDataAction save(String userroledataaction_id, UserRoleDataAction userroledataaction) {
        return client.save(userroledataaction_id, userroledataaction);
    }

	public UserRoleDataAction create(UserRoleDataAction userroledataaction) {
        return client.create(userroledataaction);
    }

    public UserRoleDataAction update(String userroledataaction_id, UserRoleDataAction userroledataaction) {
        return client.update(userroledataaction_id, userroledataaction);
    }

    public UserRoleDataAction getDraft(String userroledataaction_id, UserRoleDataAction userroledataaction) {
        return client.getDraft(userroledataaction_id, userroledataaction);
    }

    public UserRoleDataAction get( String userroledataaction_id) {
        return client.get( userroledataaction_id);
    }

    public boolean checkKey(UserRoleDataAction userroledataaction) {
        return client.checkKey(userroledataaction);
    }

    public boolean remove( String userroledataaction_id) {
        return client.remove( userroledataaction_id);
    }

	public Page<UserRoleDataAction> fetchDefault(UserRoleDataActionSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
