
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserRoleDataScope;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserRoleDataScopeFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserRoleDataScopeService {

    UserRoleDataScopeFeignClient client;

    @Autowired
    public UserRoleDataScopeService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDataScopeFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDataScopeFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

	public UserRoleDataScope create(UserRoleDataScope userroledatascope) {
        return client.create(userroledatascope);
    }

    public UserRoleDataScope save(String userroledatascope_id, UserRoleDataScope userroledatascope) {
        return client.save(userroledatascope_id, userroledatascope);
    }

    public boolean checkKey(UserRoleDataScope userroledatascope) {
        return client.checkKey(userroledatascope);
    }

    public UserRoleDataScope getDraft(String userroledatascope_id, UserRoleDataScope userroledatascope) {
        return client.getDraft(userroledatascope_id, userroledatascope);
    }

    public UserRoleDataScope update(String userroledatascope_id, UserRoleDataScope userroledatascope) {
        return client.update(userroledatascope_id, userroledatascope);
    }

    public UserRoleDataScope get( String userroledatascope_id) {
        return client.get( userroledatascope_id);
    }

    public boolean remove( String userroledatascope_id) {
        return client.remove( userroledatascope_id);
    }

	public Page<UserRoleDataScope> fetchDefault(UserRoleDataScopeSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
