
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserRoleDatas;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserRoleDatasFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserRoleDatasService {

    UserRoleDatasFeignClient client;

    @Autowired
    public UserRoleDatasService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDatasFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDatasFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

    public UserRoleDatas save(String userroledatas_id, UserRoleDatas userroledatas) {
        return client.save(userroledatas_id, userroledatas);
    }

	public UserRoleDatas create(UserRoleDatas userroledatas) {
        return client.create(userroledatas);
    }

    public UserRoleDatas update(String userroledatas_id, UserRoleDatas userroledatas) {
        return client.update(userroledatas_id, userroledatas);
    }

    public boolean checkKey(UserRoleDatas userroledatas) {
        return client.checkKey(userroledatas);
    }

    public UserRoleDatas get( String userroledatas_id) {
        return client.get( userroledatas_id);
    }

    public UserRoleDatas getDraft(String userroledatas_id, UserRoleDatas userroledatas) {
        return client.getDraft(userroledatas_id, userroledatas);
    }

    public boolean remove( String userroledatas_id) {
        return client.remove( userroledatas_id);
    }

	public Page<UserRoleDatas> fetchDefault(UserRoleDatasSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
