
package cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.service;

import java.util.ArrayList;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.openfeign.ribbon.LoadBalancerFeignClient;
import org.springframework.stereotype.Service;

import feign.Client;
import feign.Contract;
import feign.Feign;
import feign.codec.Decoder;
import feign.codec.Encoder;

import com.alibaba.fastjson.JSONObject;

import org.springframework.util.DigestUtils;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import cn.ibizlab.r7.runtime.util.feign.suport.SearchContextFeignEncode;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.domain.UserRoleDetail;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.filter.*;
import cn.ibizlab.r7.runtime.runtimemgr.r7rt_base.feign.UserRoleDetailFeignClient;
import cn.ibizlab.r7.runtime.runtimemgr.RuntimeMgrApplication.RuntimeMgrClientProperties;
import cn.ibizlab.r7.runtime.util.feign.FeignRequestInterceptor;

@Service
public class UserRoleDetailService {

    UserRoleDetailFeignClient client;

    @Autowired
    public UserRoleDetailService(Decoder decoder, Encoder encoder, Client client, Contract contract, FeignRequestInterceptor feignRequestInterceptor,
                                    RuntimeMgrClientProperties runtimemgrClientProperties) {
        if (runtimemgrClientProperties.getServiceId()!=null) {
    		Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDetailFeignClient.class,"http://" + runtimemgrClientProperties.getServiceId() + "/") ;
		} else if (runtimemgrClientProperties.getServiceUrl()!=null) {
			if (client instanceof LoadBalancerFeignClient) {
				client = ((LoadBalancerFeignClient) client).getDelegate();
			}
			Feign.Builder nameBuilder = Feign.builder()
                    .client(client)
                    .encoder(new SearchContextFeignEncode(encoder))
                    .decoder(decoder)
                    .contract(contract)
                    .requestInterceptor(feignRequestInterceptor)
                    ;
        	this.client = nameBuilder.target(UserRoleDetailFeignClient.class, "http://" + runtimemgrClientProperties.getServiceUrl() + "/") ;
		}
    }

    public boolean remove( String userroledetail_id) {
        return client.remove( userroledetail_id);
    }

    public UserRoleDetail update(String userroledetail_id, UserRoleDetail userroledetail) {
        return client.update(userroledetail_id, userroledetail);
    }

    public UserRoleDetail save(String userroledetail_id, UserRoleDetail userroledetail) {
        return client.save(userroledetail_id, userroledetail);
    }

	public UserRoleDetail create(UserRoleDetail userroledetail) {
        return client.create(userroledetail);
    }

    public UserRoleDetail getDraft(String userroledetail_id, UserRoleDetail userroledetail) {
        return client.getDraft(userroledetail_id, userroledetail);
    }

    public boolean checkKey(UserRoleDetail userroledetail) {
        return client.checkKey(userroledetail);
    }

    public UserRoleDetail get( String userroledetail_id) {
        return client.get( userroledetail_id);
    }

	public Page<UserRoleDetail> fetchDefault(UserRoleDetailSearchContext searchContext) {
        return client.fetchDefault(searchContext);
    }

}
